@@ -57,7 +57,7 @@
   <?php if (isset($fields['mediafiles']) && isset($fields['mediafiles']->content)): ?>
   <div class="information-row asset-formats">
     <h3><?php print t('Format'); ?></h3>
-    <p><?php print t('The media is available in mp4 format'); ?>:</p>
+    <p><?php print t('The media is available in the format(s)'); ?>:</p>
     <?php print $fields['mediafiles']->content; ?>
   </div>
   <?php endif; ?>
