@@ -28,7 +28,7 @@
   <?php if ($fields['granted']->raw == 'TRUE'): ?>
     <?php print $fields['still_url']->content; ?>
   <?php else: ?>
-<?php print l(theme('image', array('path' => drupal_get_path('theme', 'sitebuilder_uvt') . '/images/notgranted-thumb.png', 'width' => '300px', 'height' => '170px', 'alt' => t("You don't have the right permissions to access this video"))), 'asset/detail/' . $fields['asset_id']->raw, array('html' => TRUE, 'attributes' => array('class' => 'views-field-still-url'))); ?>
+<?php print l(theme('image', array('path' => drupal_get_path('theme', 'sitebuilder_uvt') . '/images/notgranted-thumb.png', 'width' => '300px', 'height' => '170px', 'alt' => t("You don't have the right permissions to access this media"))), 'asset/detail/' . $fields['asset_id']->raw, array('html' => TRUE, 'attributes' => array('class' => 'views-field-still-url'))); ?>
   <?php endif; ?>
 <?php endif; ?>
 
